@@ -65,7 +65,8 @@ def get_q_compo(dx: float, dy: float, detector_distance: float, wavelength: floa
 
 def flip_phi(phi: float) -> float:
     """
-    Correct phi to within the 0 <= to <= 2pi range
+    Force phi to be within the 0 <= to <= 2pi range by adding or subtracting
+    2pi as necessary
 
     :return: phi in >=0 and <=2Pi
     """
@@ -281,15 +282,25 @@ class Binning:
 
     def __init__(self, min_value, max_value, n_bins, base=None):
         """
-        if base is None: Linear binning
+        :param min_value: the value defining the start of the binning interval.
+        :param max_value: the value defining the end of the binning interval.
+        :param n_bins: the number of bins.
+        :param base: the base used for log, linear binning if None.
+
+        Beware that min_value should always be numerically smaller than
+        max_value. Take particular care when binning angles across the
+        2pi to 0 discontinuity.
         """
-        self.min = min_value if min_value > 0 else 0.0001
+        self.min = min_value
         self.max = max_value
         self.n_bins = n_bins
         self.base = base
 
     def get_bin_index(self, value):
         """
+        :param value: the value in the binning interval whose bin index should
+                      be returned. Must be between min_value and max_value.
+
         The general formula logarithm binning is:
         bin = floor(N * (log(x) - log(min)) / (log(max) - log(min)))
         """
@@ -351,19 +362,42 @@ class _Slab:
         qy_data = data2D.qy_data[np.isfinite(data2D.data)]
         mask_data = data2D.mask[np.isfinite(data2D.data)]
 
+        # Bin width calculation returns negative values when either axis has no points above 0.
+        self.bin_width = abs(self.bin_width)
+
         # Build array of Q intervals
         if maj == 'x':
             if self.fold:
-                x_min = 0
+                # Set x_max based on which is further from Qx = 0
+                x_max = max(abs(self.x_min),abs(self.x_max))
+                # Set x_min based on which is closer to Qx = 0, but will have different limits depending on whether
+                # x_min and x_max are on the same side of Qx = 0
+                if self.x_min*self.x_max >= 0: # If on same side
+                    x_min = min(abs(self.x_min),abs(self.x_max))
+                else:
+                    x_min = 0
             else:
+                x_max = self.x_max
                 x_min = self.x_min
-            nbins = int(math.ceil((self.x_max - x_min) / self.bin_width))
+            y_max = self.y_max
+            y_min = self.y_min
+            nbins = int(math.ceil((x_max - x_min) / self.bin_width))
         elif maj == 'y':
             if self.fold:
-                y_min = 0
+                # Set y_max based on which is further from Qy = 0
+                y_max = max(abs(self.y_min), abs(self.y_max))
+                # Set y_min based on which is closer to Qy = 0, but will have different limits depending on whether
+                # y_min and y_max are on the same side of Qy = 0
+                if self.y_min * self.y_max >= 0:  # If on same side
+                    y_min = min(abs(self.y_min), abs(self.y_max))
+                else:
+                    y_min = 0
             else:
+                y_max = self.y_max
                 y_min = self.y_min
-            nbins = int(math.ceil((self.y_max - y_min) / self.bin_width))
+            x_max = self.x_max
+            x_min = self.x_min
+            nbins = int(math.ceil((y_max - y_min) / self.bin_width))
         else:
             raise RuntimeError("_Slab._avg: unrecognized axis %s" % str(maj))
 
@@ -381,10 +415,24 @@ class _Slab:
             frac_x = 0
             frac_y = 0
             # get ROI
-            if self.x_min <= qx_data[npts] and self.x_max > qx_data[npts]:
-                frac_x = 1
-            if self.y_min <= qy_data[npts] and self.y_max > qy_data[npts]:
-                frac_y = 1
+            if self.fold:
+                # If folded, need to satisfy absolute value of Q, but also make sure we're only pulling
+                # from data inside the box (an issue when the box is not centered on 0)
+                if maj == 'x':
+                    if self.x_min <= qx_data[npts] < self.x_max and x_min <= abs(qx_data[npts]) < x_max:
+                        frac_x = 1
+                    if self.y_min <= qy_data[npts] < self.y_max:
+                        frac_y = 1
+                elif maj == 'y': # The case where maj != 'x' or 'y' was handled earlier
+                    if self.y_min <= qy_data[npts] < self.y_max and y_min <= abs(qy_data[npts]) < y_max:
+                        frac_y = 1
+                    if self.x_min <= qx_data[npts] < self.x_max:
+                        frac_x = 1
+            else:
+                if self.x_min <= qx_data[npts] < self.x_max:
+                    frac_x = 1
+                if self.y_min <= qy_data[npts] < self.y_max:
+                    frac_y = 1
             frac = frac_x * frac_y
 
             if frac == 0:
@@ -798,23 +846,20 @@ class Ring:
         if not idx.any():
             msg = "Average Error: No points inside ROI to average..."
             raise ValueError(msg)
-        # elif len(phi_bins[idx])!= self.nbins_phi:
-        #    print "resulted",self.nbins_phi- len(phi_bins[idx])
-        #,"empty bin(s) due to tight binning..."
+
         return Data1D(x=phi_values[idx], y=phi_bins[idx], dy=phi_err[idx])
 
 
 class _Sector:
     """
     Defines a sector region on a 2D data set.
-    The sector is defined by r_min, r_max, phi_min, phi_max,
-    and the position of the center of the ring
-    where phi_min and phi_max are defined by the right
-    and left lines wrt central line
-    and phi_max could be less than phi_min.
+    The sector is defined by r_min, r_max, phi_min and phi_max.
+    phi_min and phi_max are defined by the right and left lines wrt a central
+    line such that phi_max could be less than phi_min if they straddle the
+    discontinuity from 2pi to 0.
 
     Phi is defined between 0 and 2*pi in anti-clockwise
-    starting from the x- axis on the left-hand side
+    starting from the negative x-axis.
     """
 
     def __init__(self, r_min, r_max, phi_min=0, phi_max=2 * math.pi, nbins=20,
@@ -830,19 +875,22 @@ class _Sector:
         self.nbins = nbins
         self.base = base
 
+        # set up to use the asymmetric sector average - default to symmetric
+        self.fold = True
+
     def _agv(self, data2D, run='phi'):
         """
         Perform sector averaging.
 
         :param data2D: Data2D object
-        :param run:  define the varying parameter ('phi' , 'q' , or 'q2')
+        :param run:  define the varying parameter ('phi' , or 'sector')
 
         :return: Data1D object
         """
         if data2D.__class__.__name__ not in ["Data2D", "plottable_2D"]:
             raise RuntimeError("Ring averaging only take plottable_2D objects")
 
-        # Get the all data & info
+        # Get all the data & info
         data = data2D.data[np.isfinite(data2D.data)]
         q_data = data2D.q_data[np.isfinite(data2D.data)]
         err_data = data2D.err_data[np.isfinite(data2D.data)]
@@ -864,12 +912,28 @@ class _Sector:
         # Get the min and max into the region: 0 <= phi < 2Pi
         phi_min = flip_phi(self.phi_min)
         phi_max = flip_phi(self.phi_max)
+        # Now calculate the angles for the opposite side sector, here referred
+        # to as "minor wing," and ensure these too are within 0 to 2pi
+        phi_min_minor = flip_phi(phi_min - math.pi)
+        phi_max_minor = flip_phi(phi_max - math.pi)
 
-        #  binning object
+        #  set up the bins by creating a binning object
         if run.lower() == 'phi':
-            binning = Binning(self.phi_min, self.phi_max, self.nbins, self.base)
-        else:
+            # The check here ensures when a range straddles the discontinuity
+            # inherent in circular angles (jumping from 2pi to 0) that the
+            # Binning class still recieves a continuous interval. phi_min/max
+            # are used here instead of self.phi_min/max as they are always in
+            # the range 0, 2pi - making their values more predictable.
+            # Note that their values must not be altered, as they are used to
+            # determine what points (also in the range 0, 2pi) are in the ROI.
+            if phi_min > phi_max:
+                binning = Binning(phi_min, phi_max + 2 * np.pi, self.nbins, self.base)
+            else:
+                binning = Binning(phi_min, phi_max, self.nbins, self.base)
+        elif self.fold:
             binning = Binning(self.r_min, self.r_max, self.nbins, self.base)
+        else:
+            binning = Binning(-self.r_max, self.r_max, self.nbins, self.base)
 
         for n in range(len(data)):
             if not mask_data[n]:
@@ -883,29 +947,18 @@ class _Sector:
             # Is pixel within range?
             is_in = False
 
-            # phi-value of the pixel (j,i)
+            # calculate the phi-value of the pixel (j,i) and convert the range
+            # [-pi,pi] returned by the atan2 function to the [0,2pi] range used
+            # as the reference frame for these calculations
             phi_value = math.atan2(qy_data[n], qx_data[n]) + math.pi
 
             # No need to calculate: data outside of the radius
             if self.r_min > q_value or q_value > self.r_max:
                 continue
 
-            # In case of two ROIs (symmetric major and minor regions)(for 'q2')
-            if run.lower() == 'q2':
-                # For minor sector wing
-                # Calculate the minor wing phis
-                phi_min_minor = flip_phi(phi_min - math.pi)
-                phi_max_minor = flip_phi(phi_max - math.pi)
-                # Check if phis of the minor ring is within 0 to 2pi
-                if phi_min_minor > phi_max_minor:
-                    is_in = (phi_value > phi_min_minor or
-                             phi_value < phi_max_minor)
-                else:
-                    is_in = (phi_value > phi_min_minor and
-                             phi_value < phi_max_minor)
-
-            # For all cases(i.e.,for 'q', 'q2', and 'phi')
-            # Find pixels within ROI
+            # For all cases(i.e.,for 'sector' (fold true or false), and 'phi')
+            # Find pixels within the main ROI (primary sector (main wing)
+            # in the case of sectors)
             if phi_min > phi_max:
                 is_in = is_in or (phi_value > phi_min or
                                   phi_value < phi_max)
@@ -913,13 +966,40 @@ class _Sector:
                 is_in = is_in or (phi_value >= phi_min and
                                   phi_value < phi_max)
 
+            # For sector cuts we need to check if the point is within the
+            # "minor wing" before checking if it is in the major wing.
+            # There are effectively two ROIs here as each sector on opposite
+            # sides of 0,0 need to be checked separately.
+            if run.lower() == 'sector' and not is_in:
+                if phi_min_minor > phi_max_minor:
+                    is_in = (phi_value > phi_min_minor or
+                             phi_value < phi_max_minor)
+                else:
+                    is_in = (phi_value > phi_min_minor and
+                             phi_value < phi_max_minor)
+                # now, if we want to keep both sides separate we arbitrarily,
+                # assign negative q to the qs in the minor wing. As calculated,
+                # all qs are postive and in fact all qs in the same ring are
+                # the same. This will allow us to plot both sides of 0,0
+                # independently.
+                if not self.fold:
+                    if is_in:
+                        q_value *= -1
+
             # data oustide of the phi range
             if not is_in:
                 continue
 
             # Get the binning index
             if run.lower() == 'phi':
-                i_bin = binning.get_bin_index(phi_value)
+                # If the original range used to instantiate `binning` was
+                # shifted by 2pi to accommodate the 2pi to 0 discontinuity,
+                # then phi_value needs to be shifted too so that it falls in
+                # the continuous range set up for the binning process.
+                if phi_min > phi_value:
+                    i_bin = binning.get_bin_index(phi_value + 2 * np.pi)
+                else:
+                    i_bin = binning.get_bin_index(phi_value)
             else:
                 i_bin = binning.get_bin_index(q_value)
 
@@ -951,11 +1031,19 @@ class _Sector:
         with np.errstate(divide='ignore', invalid='ignore'):
             y = y/y_counts
             y_err = np.sqrt(y_err)/y_counts
-            # The type of averaging: phi, q2, or q
-            # Calculate x values at the center of the bin
+            # Calculate x values at the center of the bin depending on the
+            # the type of averaging (phi or sector)
             if run.lower() == 'phi':
-                step = (self.phi_max - self.phi_min) / self.nbins
-                x = (np.arange(self.nbins) + 0.5) * step + self.phi_min
+                # Determining the step size is best done via the binning
+                # object's interval, as this is set up so max > min in all
+                # cases. One could also use phi_min and phi_max, so long as
+                # they have not been changed.
+                # In setting up x, phi_min makes a better starting point than
+                # self.phi_min, as the resulting array is garenteed to be > 0
+                # throughout. This works better with the sasview gui, which
+                # will convert the result to the range -pi, pi.
+                step = (binning.max - binning.min) / self.nbins
+                x = (np.arange(self.nbins) + 0.5) * step + phi_min
             else:
                 # set q to the average of the q values within each bin
                 x = x/y_counts
@@ -975,9 +1063,6 @@ class _Sector:
         if not idx.any():
             msg = "Average Error: No points inside sector of ROI to average..."
             raise ValueError(msg)
-        # elif len(y[idx])!= self.nbins:
-        #    print "resulted",self.nbins- len(y[idx]),
-        # "empty bin(s) due to tight binning..."
         return Data1D(x=x[idx], y=y[idx], dy=y_err[idx], dx=d_x)
 
 
@@ -1002,11 +1087,14 @@ class SectorPhi(_Sector):
 
 class SectorQ(_Sector):
     """
-    Sector average as a function of Q for both symatric wings.
-    I(Q) is return and the data is averaged over phi.
+    Sector average as a function of Q for both wings. setting the _Sector.fold
+    attribute determines whether or not the two sectors are averaged together
+    (folded over) or separate.  In the case of separate (not folded), the
+    qs for the "minor wing" are arbitrarily set to a negative value.
+    I(Q) is returned and the data is averaged over phi.
 
     A sector is defined by r_min, r_max, phi_min, phi_max.
-    r_min, r_max, phi_min, phi_max >0.
+    where r_min, r_max, phi_min, phi_max >0.
     The number of bin in Q also has to be defined.
     """
 
@@ -1018,7 +1106,7 @@ class SectorQ(_Sector):
 
         :return: Data1D object
         """
-        return self._agv(data2D, 'q2')
+        return self._agv(data2D, 'sector')
 
 ################################################################################
 
